## Can I load data into Select2 using an array?

Yes, but only when you are initially creating it.

### What properties are required on the objects passed in to the array?

The `id` and `text` properties are required on each object, and these are the properties that Select2 uses for the internal data objects. Any additional paramters passed in with data objects will be included on the data objects that Select2 exposes.

### How should nested results be formatted?

### How many levels of nesting are allowed?

Because Select2 falls back to an `<optgroup>` when creating nested options, only a single level of nesting can be supported.

### Why are `<option>` tags being created?

The `data` option is a shortcut that Select2 provides which allows you to load options into your `select` from a data array.

### My objects don't use `id` for their unique identifiers, what can I do?

You can re-map your identifier before passing it to Select2.

### My objects use a property other than `text` for the text that needs to be displayed

These can also be re-mapped.